==> zio-aws-textract_2.12-5.17.204.1-sources.jar: zio/aws/textract/model/StartExpenseAnalysisResponse.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.textract.model.primitives.JobId
import scala.jdk.CollectionConverters._
final case class StartExpenseAnalysisResponse(
    jobId: Optional[JobId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse = {
    import StartExpenseAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly =
    zio.aws.textract.model.StartExpenseAnalysisResponse.wrap(buildAwsValue())
}
object StartExpenseAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.StartExpenseAnalysisResponse =
      zio.aws.textract.model
        .StartExpenseAnalysisResponse(jobId.map(value => value))
    def jobId: Optional[JobId]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ) extends zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly {
    override val jobId: Optional[JobId] = zio.aws.core.internal
      .optionalFromNullable(impl.jobId())
      .map(value => zio.aws.textract.model.primitives.JobId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ): zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-textract_2.13-5.17.127.1-sources.jar: zio/aws/textract/model/StartExpenseAnalysisResponse.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.textract.model.primitives.JobId
import scala.jdk.CollectionConverters._
final case class StartExpenseAnalysisResponse(jobId: Option[JobId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse = {
    import StartExpenseAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly =
    zio.aws.textract.model.StartExpenseAnalysisResponse.wrap(buildAwsValue())
}
object StartExpenseAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.StartExpenseAnalysisResponse =
      zio.aws.textract.model
        .StartExpenseAnalysisResponse(jobId.map(value => value))
    def jobId: Option[JobId]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ) extends zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly {
    override val jobId: Option[JobId] = scala
      .Option(impl.jobId())
      .map(value => zio.aws.textract.model.primitives.JobId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.StartExpenseAnalysisResponse
  ): zio.aws.textract.model.StartExpenseAnalysisResponse.ReadOnly = new Wrapper(
    impl
  )
}
